@@ -469,7 +469,7 @@ sub git_commit_info ($;$) {
 
 	my @raw_lines = run_or_die('git', 'log', @opts,
 		'--pretty=raw', '--raw', '--abbrev=40', '--always', '-c',
-		'-r', $sha1, '--', '.');
+		'-r', $sha1, '--no-renames', '--', '.');
 
 	my @ci;
 	while (my $parsed = parse_diff_tree(\@raw_lines)) {
@@ -973,7 +973,9 @@ sub rcs_revert ($) {
 
 	ensure_committer();
 
-	if (run_or_non('git', 'revert', '--no-commit', $sha1)) {
+	if (run_or_non('git', 'revert', '--strategy=recursive',
+			'--strategy-option=no-renames',
+			'--no-commit', $sha1)) {
 		return undef;
 	}
 	else {
